RCIMIWAreaCode enum

Inheritance
Available extensions

Values

bj → const RCIMIWAreaCode

ZH

北京数据中心,默认值

EN

Beijing Data Center, default value

sg → const RCIMIWAreaCode

ZH

新加坡数据中心 EN

Singapore Data Center

na → const RCIMIWAreaCode

ZH

北美数据中心 EN

North America Data Center

sgB → const RCIMIWAreaCode

ZH

新加坡 B 企业合作数据中心

EN

Singapore B Enterprise Collaboration Data Center

sa → const RCIMIWAreaCode

ZH

沙特数据中心

EN

China (Beijing) Data Center

om → const RCIMIWAreaCode

ZH

阿曼数据中心

EN

Oman Data Center

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWAreaCode>
A constant List of the values in this enum, in order of their declaration.