data property

String? data
getter/setter pair

ZH

命令的扩展数据,可以为任意字符串,如存放您定义的json数据。

EN

The extension data of the command, which can be any string, such as storing your custom JSON data.

Implementation

String? data;