RCIMIWCompressOptions class

Constructors

RCIMIWCompressOptions.create({int? originalImageQuality, int? originalImageSize, int? originalImageMaxSize, int? thumbnailQuality, int? thumbnailMaxSize, int? thumbnailMinSize, int? sightCompressWidth, int? sightCompressHeight, int? locationThumbnailQuality, int? locationThumbnailWidth, int? locationThumbnailHeight})
RCIMIWCompressOptions.fromJson(Map<String, dynamic> json)

Properties

hashCode int
The hash code for this object.
no setterinherited
locationThumbnailHeight int?
ZH
getter/setter pair
locationThumbnailQuality int?
ZH
getter/setter pair
locationThumbnailWidth int?
ZH
getter/setter pair
originalImageMaxSize int?
ZH
getter/setter pair
originalImageQuality int?
ZH
getter/setter pair
originalImageSize int?
ZH
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sightCompressHeight int?
ZH
getter/setter pair
sightCompressWidth int?
ZH
getter/setter pair
thumbnailMaxSize int?
ZH
getter/setter pair
thumbnailMinSize int?
ZH
getter/setter pair
thumbnailQuality int?
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited