RCIMIWConversation class

Constructors

RCIMIWConversation.create({RCIMIWConversationType? conversationType, String? targetId, String? channelId, int? unreadCount, int? mentionedCount, int? mentionedMeCount, bool? top, String? draft, RCIMIWMessage? lastMessage, RCIMIWPushNotificationLevel? notificationLevel, int? firstUnreadMsgSendTime, int? operationTime, RCIMIWTranslateStrategy? translateStrategy})
RCIMIWConversation.fromJson(Map<String, dynamic> json)

Properties

channelId String?
ZH
getter/setter pair
conversationType RCIMIWConversationType?
ZH
getter/setter pair
draft String?
ZH
getter/setter pair
firstUnreadMsgSendTime int?
ZH
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastMessage RCIMIWMessage?
ZH
getter/setter pair
mentionedCount int?
ZH
getter/setter pair
mentionedMeCount int?
ZH
getter/setter pair
notificationLevel RCIMIWPushNotificationLevel?
ZH
getter/setter pair
operationTime int?
ZH
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetId String?
ZH
getter/setter pair
top bool?
ZH
getter/setter pair
translateStrategy RCIMIWTranslateStrategy?
ZH
getter/setter pair
unreadCount int?
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited