RCIMIWConversationType enum

Inheritance
Available extensions

Values

invalid → const RCIMIWConversationType

ZH

暂不支持,SDK 保留类型,开发者不可使用

EN

Not supported. Reserved type for SDK, not available for developers.

private → const RCIMIWConversationType

ZH

单聊会话

EN

One-to-One Chat Conversation

group → const RCIMIWConversationType

ZH

群聊会话

EN

Group Chat Conversation

chatroom → const RCIMIWConversationType

ZH

聊天室会话

EN

Chatroom Conversation

system → const RCIMIWConversationType

ZH

系统会话

EN

System Conversation

ultraGroup → const RCIMIWConversationType

ZH

超级群会话

EN

Ultra Group Conversation

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWConversationType>
A constant List of the values in this enum, in order of their declaration.