addChatRoomEntry method

Future<int> addChatRoomEntry(
  1. String targetId,
  2. String key,
  3. String value,
  4. bool deleteWhenLeft,
  5. bool overwrite, {
  6. IRCIMIWAddChatRoomEntryCallback? callback,
})

ZH

设置聊天室自定义属性。

  • targetId 聊天室会话 ID
  • key 聊天室属性名称,Key 支持大小写英文字母、数字、部分特殊符号 + = - _ 的组合方式,最大长度 128 个字符
  • value 聊天室属性对应的值,最大长度 4096 个字符
  • deleteWhenLeft 用户掉线或退出时,是否自动删除该 Key、Value 值
  • overwrite 如果当前 key 存在,是否进行覆盖
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onChatRoomEntryAdded

EN

Set chatroom custom attributes.

  • targetId The conversation ID of the chatroom.
  • key The name of the chatroom attribute. The key supports a combination of uppercase and lowercase letters, numbers, and special characters + = - _. The maximum length is 128 characters.
  • value The value corresponding to the chatroom attribute. The maximum length is 4096 characters.
  • deleteWhenLeft Whether to automatically delete the key-value pair when the user goes offline or exits the chatroom.
  • overwrite Whether to overwrite the existing key if it already exists.
  • callback The event callback. SDK supports callback method starting from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. successful call, and the specific result needs to be implemented in the interface callback. Non-zero indicates that the current interface call operation failed, and the interface callback will not be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> addChatRoomEntry(
  String targetId,
  String key,
  String value,
  bool deleteWhenLeft,
  bool overwrite, {
  IRCIMIWAddChatRoomEntryCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.addChatRoomEntry(
    targetId,
    key,
    value,
    deleteWhenLeft,
    overwrite,
    callback: callback,
  );
}