addToBlacklist method
ZH
将某个用户加入黑名单。 当你把对方加入黑名单后,对方再发消息时,就会提示“已被加入黑名单,消息发送失败”。 但你依然可以发消息个对方。
userId用户 Idcallback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onBlacklistAdded
EN
Add a user to the blocklist. When you add a user to the blocklist, they will receive a notification stating "You have been added to the blocklist, message sending failed" when attempting to send you a message. However, you can still send messages to them.
userIdUser IDcallbackEvent callback. The SDK has supported callback-style callbacks since version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero indicates that the current interface call operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.
此接口不支持 Flutter For Web 端
Implementation
Future<int> addToBlacklist(String userId, {IRCIMIWAddToBlacklistCallback? callback}) async {
return RCIMWrapperPlatform.instance.addToBlacklist(userId, callback: callback);
}