changeConversationTypeNotificationLevel method

Future<int> changeConversationTypeNotificationLevel(
  1. RCIMIWConversationType type,
  2. RCIMIWPushNotificationLevel level, {
  3. IRCIMIWChangeConversationTypeNotificationLevelCallback? callback,
})

ZH

设置会话类型的消息提醒状态 注:如要移除消息提醒状态,设置level为RCIMIWPushNotificationLevelDefault

  • type 会话类型
  • level 消息通知级别
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onConversationTypeNotificationLevelChanged

EN

Set the message notification level for a conversation type Note: To remove the message notification level, set the level to RCIMIWPushNotificationLevelDefault.

  • type The conversation type
  • level The message notification level
  • callback The event callback. The SDK supports callback-based event handling starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be handled in the interface callback. A non-zero value indicates that the operation failed, and the interface callback will not be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> changeConversationTypeNotificationLevel(
  RCIMIWConversationType type,
  RCIMIWPushNotificationLevel level, {
  IRCIMIWChangeConversationTypeNotificationLevelCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.changeConversationTypeNotificationLevel(type, level, callback: callback);
}