changeUltraGroupChannelDefaultNotificationLevel method

Future<int> changeUltraGroupChannelDefaultNotificationLevel(
  1. String targetId,
  2. String? channelId,
  3. RCIMIWPushNotificationLevel level, {
  4. IRCIMIWChangeUltraGroupChannelDefaultNotificationLevelCallback? callback,
})

ZH

设置超级群频道的默认消息状态

  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用。
  • level 消息通知级别
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onUltraGroupChannelDefaultNotificationLevelChanged

EN

Set the default message status for an ultra group channel

  • targetId The conversation ID
  • channelId The channel ID, only supported for ultra groups
  • level The message notification level
  • callback The event callback. The SDK has supported callback-based event handling since version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero values indicate that the current interface call failed, and the interface callback will not be triggered. For detailed error information, refer to the error codes.

Implementation

Future<int> changeUltraGroupChannelDefaultNotificationLevel(
  String targetId,
  String? channelId,
  RCIMIWPushNotificationLevel level, {
  IRCIMIWChangeUltraGroupChannelDefaultNotificationLevelCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.changeUltraGroupChannelDefaultNotificationLevel(
    targetId,
    channelId,
    level,
    callback: callback,
  );
}