clearUltraGroupMessages method

Future<int> clearUltraGroupMessages(
  1. String targetId,
  2. String? channelId,
  3. int timestamp,
  4. RCIMIWMessageOperationPolicy policy, {
  5. IRCIMIWClearUltraGroupMessagesCallback? callback,
})

ZH

删除超级群指定时间之前的消息

  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用。
  • timestamp 时间戳
  • policy 清除策略
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onUltraGroupMessagesCleared

EN

Delete messages in an ultra group before a specified time

  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups.
  • timestamp Unix timestamp
  • policy Clear policy
  • callback Event callback. SDK supports callback method from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. and the specific result needs to be implemented through the interface callback. Non-zero indicates a failure in the current operation, and the interface callback will not be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> clearUltraGroupMessages(
  String targetId,
  String? channelId,
  int timestamp,
  RCIMIWMessageOperationPolicy policy, {
  IRCIMIWClearUltraGroupMessagesCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.clearUltraGroupMessages(
    targetId,
    channelId,
    timestamp,
    policy,
    callback: callback,
  );
}