clearUnreadCount method

Future<int> clearUnreadCount(
  1. RCIMIWConversationType type,
  2. String targetId,
  3. String? channelId,
  4. int timestamp, {
  5. IRCIMIWClearUnreadCountCallback? callback,
})

ZH

清除某个会话中的未读消息数。 注:不支持聊天室!

  • type 会话类型
  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • timestamp 该会话已阅读的最后一条消息的发送时间戳,清除所有传入当前最新时间戳
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onUnreadCountCleared

EN

Clear the unread message count for a specific conversation. Note: Not supported for chatrooms!

  • type Conversation type
  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups. Pass null for other conversation types.
  • timestamp The timestamp of the last read message in the conversation. Pass the latest timestamp to clear all.
  • callback Event callback. The SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and will be removed in the 6.x version. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be handled by the callback. Non-zero values indicate the operation failed, and no callback will be triggered. Refer to the error codes for details.

Implementation

Future<int> clearUnreadCount(
  RCIMIWConversationType type,
  String targetId,
  String? channelId,
  int timestamp, {
  IRCIMIWClearUnreadCountCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.clearUnreadCount(type, targetId, channelId, timestamp, callback: callback);
}