deleteLocalMessages method

Future<int> deleteLocalMessages(
  1. List<RCIMIWMessage> messages, {
  2. IRCIMIWDeleteLocalMessagesCallback? callback,
})

ZH

删除本地消息

  • messages 消息集合
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onLocalMessagesDeleted

EN

Delete Local Messages

  • messages The collection of messages to be deleted.
  • callback The event callback. Starting from version 5.3.1, the SDK supports callback-based event handling. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in the 6.x release. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be handled in the interface callback. A non-zero value indicates that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.

此接口不支持 Flutter For Web 端

Implementation

Future<int> deleteLocalMessages(List<RCIMIWMessage> messages, {IRCIMIWDeleteLocalMessagesCallback? callback}) async {
  return RCIMWrapperPlatform.instance.deleteLocalMessages(messages, callback: callback);
}