deleteMessages method

Future<int> deleteMessages(
  1. RCIMIWConversationType type,
  2. String targetId,
  3. String? channelId,
  4. List<RCIMIWMessage> messages, {
  5. IRCIMIWDeleteMessagesCallback? callback,
})

ZH

删除消息

  • type 会话类型
  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • messages 消息集合
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onMessagesDeleted

EN

Delete Messages

  • type Conversation type
  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups. For other conversation types, pass null.
  • messages Message collection
  • callback Event callback. SDK supports callback mode starting from version 5.3.1. Other callback methods for this interface are deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. invocation. Specific results need to be implemented through the interface callback. Non-zero values indicate failure in the current operation, and no interface callback will be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> deleteMessages(
  RCIMIWConversationType type,
  String targetId,
  String? channelId,
  List<RCIMIWMessage> messages, {
  IRCIMIWDeleteMessagesCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.deleteMessages(type, targetId, channelId, messages, callback: callback);
}