getBatchRemoteUltraGroupMessages method

Future<int> getBatchRemoteUltraGroupMessages(
  1. List<RCIMIWMessage> messages, {
  2. IRCIMIWGetBatchRemoteUltraGroupMessagesCallback? callback,
})

ZH

从服务获取批量消息

  • messages 获取的消息集合
  • callback 事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Retrieve Batch Messages from Service

  • messages The collection of messages retrieved.
  • callback The event callback. Starting from SDK version 5.3.1, callback is supported. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero values indicate that the current operation failed, and no interface callback will be triggered. For detailed error information, refer to the error codes. @listener onBatchRemoteUltraGroupMessagesLoaded

Implementation

Future<int> getBatchRemoteUltraGroupMessages(
  List<RCIMIWMessage> messages, {
  IRCIMIWGetBatchRemoteUltraGroupMessagesCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.getBatchRemoteUltraGroupMessages(messages, callback: callback);
}