getBlacklist method
ZH
获取当前用户设置的黑名单列表。
callback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve the current user's blocklist.
callbackEvent callback. The SDK has supported callback-style responses since version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be handled in the interface callback. Non-zero values indicate that the current interface call failed, and no interface callback will be triggered. For detailed error information, refer to the error codes. @listener onBlacklistLoaded 此接口不支持 Flutter For Web 端
Implementation
Future<int> getBlacklist({IRCIMIWGetBlacklistCallback? callback}) async {
return RCIMWrapperPlatform.instance.getBlacklist(callback: callback);
}