getBlacklistStatus method
ZH
获取某用户是否在黑名单中。
userId用户 Idcallback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Check if a user is in the blocklist.
userIdUser IDcallbackEvent callback. The SDK supports callback-style responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. and the specific result needs to be obtained through the interface callback. Non-zero values indicate a failure in the current operation, and no interface callback will be triggered. Refer to the error codes for detailed error information. @listener onBlacklistStatusLoaded 此接口不支持 Flutter For Web 端
Implementation
Future<int> getBlacklistStatus(String userId, {IRCIMIWGetBlacklistStatusCallback? callback}) async {
return RCIMWrapperPlatform.instance.getBlacklistStatus(userId, callback: callback);
}