getConversationNotificationLevel method
Future<int>
getConversationNotificationLevel(
- RCIMIWConversationType type,
- String targetId,
- String? channelId, {
- IRCIMIWGetConversationNotificationLevelCallback? callback,
ZH
获取会话的消息提醒状态
type会话类型。请注意以下限制:超级群会话类型:如在 2022.09.01 之前开通超级群业务,默认不支持为单个超级群会话所有消息设置免打扰级别(“所有消息”指所有频道中的消息和不属于任何频道的消息)。该接口仅设置指定超级群会话(targetId)中不属于任何频道的消息的免打扰状态级别。如需修改请提交工单。聊天室会话类型:不支持,因为聊天室消息默认不支持消息推送提醒。targetId会话 IDchannelId超级群的会话频道 ID。其他类型传 null 即可。如果传入频道 ID,则针对该指定频道设置消息免打扰级别。如果不指定频道 ID,则对所有超级群消息生效。注意:2022.09.01 之前开通超级群业务的客户,如果不指定频道 ID,则默认传 "" 空字符串,即仅针对指定超级群会话(targetId)中不属于任何频道的消息设置免打扰状态级别。如需修改请提交工单。callback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Get Conversation Notification Level
typeConversation type. Please note the following restrictions: Ultra group conversation type: If the ultra group service was activated before 2022.09.01, it does not support setting the Do Not Disturb level for all messages in a single ultra group conversation by default ("all messages" refers to messages in all channels and messages not belonging to any channel). This API only sets the Do Not Disturb level for messages in the specified ultra group conversation (targetId) that do not belong to any channel. Submit a ticket if modification is required.Chatroom conversation type: Not supported, as chatroom messages do not support push notifications by default.targetIdConversation IDchannelIdChannel ID of the ultra group conversation. Passnullfor other types. If a channel ID is provided, the Do Not Disturb level will be set for messages in that specific channel. If no channel ID is specified, it will apply to all ultra group messages.Note: For customers who activated the ultra group service before 2022.09.01, if no channel ID is specified, pass an empty string""by default, which means the Do Not Disturb level will only be set for messages in the specified ultra group conversation (targetId) that do not belong to any channel. Submit a ticket if modification is required.callbackEvent callback. The SDK supports callback-style response starting from version 5.3.1. Other callback methods for this API are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If thecallbackparameter is provided, only the callback will be triggered. successful call, and the specific result needs to be implemented in the callback. Non-zero values indicate that the current API call failed, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onConversationNotificationLevelLoaded
Implementation
Future<int> getConversationNotificationLevel(
RCIMIWConversationType type,
String targetId,
String? channelId, {
IRCIMIWGetConversationNotificationLevelCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.getConversationNotificationLevel(type, targetId, channelId, callback: callback);
}