getConversations method
Future<int>
getConversations(
- List<
RCIMIWConversationType> conversationTypes, - String? channelId,
- int startTime,
- int count, {
- IRCIMIWGetConversationsCallback? callback,
ZH
获取某些会话
conversationTypes会话类型channelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可startTime时间戳(毫秒),获取小于此时间戳的会话,传 0 为查询最新数据count查询的数量, 0 < count ≤ 50callback获取会话列表事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve Certain Conversations
conversationTypesSpecifies the conversation types.channelIdIndicates the channel ID, which is only supported for ultra groups. For other conversation types, pass null.startTimeRepresents the timestamp (in milliseconds) for retrieving conversations before this time. Pass 0 to query the latest data.countSpecifies the number of conversations to retrieve, where 0 < count ≤ 50.callbackIndicates the callback for retrieving the conversation list. The SDK supports callback-based retrieval starting from version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. indicates a successful call, and specific results need to be handled through the interface callback. A non-zero value indicates that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information. @listener onConversationsLoaded
Implementation
Future<int> getConversations(
List<RCIMIWConversationType> conversationTypes,
String? channelId,
int startTime,
int count, {
IRCIMIWGetConversationsCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.getConversations(
conversationTypes,
channelId,
startTime,
count,
callback: callback,
);
}