getNotificationQuietHours method

Future<int> getNotificationQuietHours({
  1. IRCIMIWGetNotificationQuietHoursCallback? callback,
})

ZH

获取已设置的时间段消息提醒屏蔽

  • callback 事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN

Get the Set Time Period for Message Reminder Blocking

  • callback Event callback. The SDK has supported callback-based event handling since version 5.3.1. Starting from version 5.4.0, other callback methods for this interface have been deprecated and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be handled in the interface callback. A non-zero value indicates that the current operation failed, and the interface callback will not be triggered. Refer to the error codes for detailed error information. @listener onNotificationQuietHoursLoaded 此接口不支持 Flutter For Web 端

Implementation

Future<int> getNotificationQuietHours({IRCIMIWGetNotificationQuietHoursCallback? callback}) async {
  return RCIMWrapperPlatform.instance.getNotificationQuietHours(callback: callback);
}