getTotalUnreadCount method

Future<int> getTotalUnreadCount(
  1. String? channelId, {
  2. IRCIMIWGetTotalUnreadCountCallback? callback,
})

ZH

获取所有未读数

  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • callback 获取所有未读数事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Get Total Unread Count

  • channelId Channel ID, supported only for ultra groups. For other conversation types, pass null.
  • callback Callback for the total unread count event. The SDK supports callback-based handling starting from version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in the 6.x version. If the callback parameter is provided, only the callback will be triggered. and the specific result needs to be handled in the callback. Non-zero values indicate a failed operation, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onTotalUnreadCountLoaded 此接口在 Flutter For Web 端不支持设置 channelId

Implementation

Future<int> getTotalUnreadCount(String? channelId, {IRCIMIWGetTotalUnreadCountCallback? callback}) async {
  return RCIMWrapperPlatform.instance.getTotalUnreadCount(channelId, callback: callback);
}