getUltraGroupAllUnreadCount method

Future<int> getUltraGroupAllUnreadCount({
  1. IRCIMIWGetUltraGroupAllUnreadCountCallback? callback,
})

ZH

获取当前用户加入的所有超级群会话的未读消息数的总和。

  • callback 事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Get the total count of unread messages from all ultra group conversations the current user has joined.

  • callback Event callback. The SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If a callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be obtained through the interface callback. Non-zero values indicate that the current interface call failed, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onUltraGroupAllUnreadCountLoaded

Implementation

Future<int> getUltraGroupAllUnreadCount({IRCIMIWGetUltraGroupAllUnreadCountCallback? callback}) async {
  return RCIMWrapperPlatform.instance.getUltraGroupAllUnreadCount(callback: callback);
}