getUltraGroupAllUnreadMentionedCount method
ZH
获取当前用户加入的所有超级群会话中的未读 @ 消息数的总和。
callback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve the total count of unread @ mentions across all ultra group
conversations the current user has joined.
callbackEvent callback. SDK supports callback-based events starting from version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback event will be triggered. successful call, and specific results need to be handled through the interface callback. Non-zero values indicate that the current interface call operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information. @listener onUltraGroupAllUnreadMentionedCountLoaded
Implementation
Future<int> getUltraGroupAllUnreadMentionedCount({
IRCIMIWGetUltraGroupAllUnreadMentionedCountCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.getUltraGroupAllUnreadMentionedCount(callback: callback);
}