getUltraGroupDefaultNotificationLevel method

Future<int> getUltraGroupDefaultNotificationLevel(
  1. String targetId, {
  2. IRCIMIWGetUltraGroupDefaultNotificationLevelCallback? callback,
})

ZH

获取超级群的默认消息状态

  • targetId 会话 ID
  • callback 事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Get the default message status of an ultra group

  • targetId The conversation ID
  • callback The event callback. The SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero values indicate that the current operation failed, and the interface callback will not be triggered. Refer to the error codes for detailed error information. @listener onUltraGroupDefaultNotificationLevelLoaded

Implementation

Future<int> getUltraGroupDefaultNotificationLevel(
  String targetId, {
  IRCIMIWGetUltraGroupDefaultNotificationLevelCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.getUltraGroupDefaultNotificationLevel(targetId, callback: callback);
}