getUltraGroupUnreadCount method

Future<int> getUltraGroupUnreadCount(
  1. String targetId, {
  2. IRCIMIWGetUltraGroupUnreadCountCallback? callback,
})

ZH

获取指定会话的未读消息数

  • targetId 会话 ID
  • callback 事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Get the unread message count for a specified conversation

  • targetId Conversation ID
  • callback Event callback. The SDK supports callback-style responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be implemented in the interface callback. A non-zero value indicates that the current operation failed, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onUltraGroupUnreadCountLoaded

Implementation

Future<int> getUltraGroupUnreadCount(String targetId, {IRCIMIWGetUltraGroupUnreadCountCallback? callback}) async {
  return RCIMWrapperPlatform.instance.getUltraGroupUnreadCount(targetId, callback: callback);
}