getUnreadCount method

Future<int> getUnreadCount(
  1. RCIMIWConversationType type,
  2. String targetId,
  3. String? channelId, {
  4. IRCIMIWGetUnreadCountCallback? callback,
})

ZH

获取某个会话的未读数 注:不支持聊天室!

  • type 会话类型
  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • callback 获取会话未读数事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Get the unread count of a conversation Note: Not supported for chatrooms!

  • type Conversation type
  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups. For other conversation types, pass null.
  • callback Callback for retrieving the unread count of the conversation. SDK supports callback-based retrieval starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented via the callback. Non-zero values indicate that the current operation failed, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onUnreadCountLoaded

Implementation

Future<int> getUnreadCount(
  RCIMIWConversationType type,
  String targetId,
  String? channelId, {
  IRCIMIWGetUnreadCountCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.getUnreadCount(type, targetId, channelId, callback: callback);
}