getUnreadMentionedMessages method

Future<int> getUnreadMentionedMessages(
  1. RCIMIWConversationType type,
  2. String targetId,
  3. String? channelId, {
  4. IRCIMIWGetUnreadMentionedMessagesCallback? callback,
})

ZH

获取会话中未读的 @ 消息。

  • type 会话类型
  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • callback 事件回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN Fetch unread @ messages in a conversation.

  • type Conversation type
  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups. Pass null for other conversation types.
  • callback Event callback. SDK supports callback-style responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. and specific results need to be handled in the interface callback. Non-zero values indicate that the current operation failed and will not trigger the interface callback. Refer to the error codes for detailed error information. @listener onUnreadMentionedMessagesLoaded 此接口不支持 Flutter For Web 端

Implementation

Future<int> getUnreadMentionedMessages(
  RCIMIWConversationType type,
  String targetId,
  String? channelId, {
  IRCIMIWGetUnreadMentionedMessagesCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.getUnreadMentionedMessages(type, targetId, channelId, callback: callback);
}