onBatchRemoteUltraGroupMessagesLoaded property

  1. @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
dynamic Function(int? code, List<RCIMIWMessage>? matchedMessages, List<RCIMIWMessage>? notMatchedMessages)? onBatchRemoteUltraGroupMessagesLoaded
getter/setter pair

ZH

loadBatchRemoteUltraGroupMessages 的接口监听

  • code 接口回调的状态码,0 代表成功,非 0 代表出现异常
  • matchedMessages 从服务获取的消息列表
  • notMatchedMessages 非法参数或者从服务没有拿到对应消息 @deprecated 请使用对应接口提供的 callback 获取结果。

EN

loadBatchRemoteUltraGroupMessages Interface Listener

  • code Indicates the status code of the interface callback. 0 represents success, while non-zero indicates an exception.
  • matchedMessages Represents the list of messages retrieved from the service.
  • matchedMessages Specifies messages that were not retrieved due to invalid parameters or absence from the service. @deprecated Please use the callback provided by the corresponding interface to obtain the results.

Implementation

@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, List<RCIMIWMessage>? matchedMessages, List<RCIMIWMessage>? notMatchedMessages)?
onBatchRemoteUltraGroupMessagesLoaded;