onChatRoomJoined property

  1. @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
dynamic Function(int? code, String? targetId)? onChatRoomJoined
getter/setter pair

ZH

joinChatRoom 的接口监听

  • code 接口回调的状态码,0 代表成功,非 0 代表出现异常
  • targetId 会话 ID @deprecated 请使用对应接口提供的 callback 获取结果。

EN

joinChatRoom interface listener

  • code Status code of the interface callback, where 0 indicates success and non-zero indicates an exception
  • targetId Conversation ID @deprecated Please use the callback provided by the corresponding interface to obtain the result.

Implementation

@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, String? targetId)? onChatRoomJoined;