onDownloadingMediaMessageCanceled property

  1. @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
dynamic Function(int? code, RCIMIWMediaMessage? message)? onDownloadingMediaMessageCanceled
getter/setter pair

ZH

cancelDownloadingMediaMessage 的接口监听

  • code 接口回调的状态码,0 代表成功,非 0 代表出现异常
  • message 取消下载的消息 @deprecated 请使用对应接口提供的 callback 获取结果。

EN

cancelDownloadingMediaMessage Interface Listener

  • code The status code of the interface callback. 0 indicates success, non-zero indicates an exception.
  • message The message for which the download was canceled. @deprecated Please use the callback provided by the corresponding interface to obtain the result.

Implementation

@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, RCIMIWMediaMessage? message)? onDownloadingMediaMessageCanceled;