onGroupMessageReadReceiptResponseReceived property

dynamic Function(String? targetId, String? messageUId, Map? respondUserIds)? onGroupMessageReadReceiptResponseReceived
getter/setter pair

ZH

收到群聊已读回执响应的监听

  • targetId 会话 ID
  • messageUId 收到回执响应的消息的 messageUId
  • respondUserIds 会话中响应了此消息的用户列表。其中 key: 用户 id ; value: 响应时间。

EN

Listener for Group Chat Read Receipt Response

  • targetId Conversation ID
  • messageUId Message UID of the message for which the read receipt response was received
  • respondUserIds List of users in the conversation who responded to this message. The key is the user ID, and the value is the response time.

Implementation

Function(String? targetId, String? messageUId, Map? respondUserIds)? onGroupMessageReadReceiptResponseReceived;