onNotificationQuietHoursLoaded property

  1. @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
dynamic Function(int? code, String? startTime, int? spanMinutes, RCIMIWPushNotificationQuietHoursLevel? level)? onNotificationQuietHoursLoaded
getter/setter pair

ZH

loadNotificationQuietHours 的接口监听

  • code 接口回调的状态码,0 代表成功,非 0 代表出现异常
  • startTime 开始消息免打扰时间
  • spanMinutes 已设置的屏蔽时间分钟数,0 < spanMinutes < 1440
  • level 消息通知级别 @deprecated 请使用对应接口提供的 callback 获取结果。

EN

loadNotificationQuietHours Interface Callback

  • code Indicates the status code of the interface callback. 0 represents success, while non-zero indicates an exception.
  • startTime Specifies the start time of the message Do Not Disturb period.
  • spanMinutes Represents the duration of the set quiet hours in minutes, where 0 < spanMinutes < 1440.
  • level Indicates the message notification level. @deprecated Please use the callback provided by the corresponding interface to retrieve the result.

Implementation

@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, String? startTime, int? spanMinutes, RCIMIWPushNotificationQuietHoursLevel? level)?
onNotificationQuietHoursLoaded;