onRemoteMessageExpansionUpdated property

dynamic Function(Map? expansion, RCIMIWMessage? message)? onRemoteMessageExpansionUpdated
getter/setter pair

ZH

消息扩展信息更改的回调

  • expansion 消息扩展信息中更新的键值对,只包含更新的键值对,不是全部的数据。如果想获取全部的键值对,请使用 message 的 expansion 属性。
  • message 发生变化的消息

EN

Callback for Message Extension Information Change

  • expansion Specifies the key-value pairs updated in the message extension information. Only the updated key-value pairs are included, not the entire dataset. To retrieve all key-value pairs, use the expansion property of the message object.
  • message Indicates the message object where the changes occurred.

在 Flutter For Web 端监听变为 onRemoteMessageExpansionUpdatedForWeb

Implementation

Function(Map? expansion, RCIMIWMessage? message)? onRemoteMessageExpansionUpdated;