onTotalUnreadCountLoaded property

  1. @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
dynamic Function(int? code, String? channelId, int? count)? onTotalUnreadCountLoaded
getter/setter pair

ZH

loadTotalUnreadCount 的接口监听

  • code 接口回调的状态码,0 代表成功,非 0 代表出现异常
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • count 未读数量 @deprecated 请使用对应接口提供的 callback 获取结果。

EN

loadTotalUnreadCount Interface Listener

  • code Indicates the status code of the interface callback. 0 represents success, non-zero indicates an exception.
  • channelId Specifies the channel ID, only supported for ultra groups. Pass null for other conversation types.
  • count Represents the unread count. @deprecated Please use the callback provided by the corresponding interface to obtain the result.

Implementation

@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, String? channelId, int? count)? onTotalUnreadCountLoaded;