onTypingStatusChanged property

dynamic Function(RCIMIWConversationType? type, String? targetId, String? channelId, List<RCIMIWTypingStatus>? userTypingStatus)? onTypingStatusChanged
getter/setter pair

ZH

会话输入状态发生变化。对于单聊而言,当对方正在输入时,监听会触发一次;当对方不处于输入状态时,该监听还会触发一次,但回调里输入用户列表为空。

  • type 会话类型
  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • userTypingStatus 发生状态变化的集合

EN

The conversation input status has changed. For one-to-one chats, the listener is triggered once when the other party is typing, and it is triggered again when the other party stops typing, but the list of typing users in the callback will be empty.

  • type Conversation type
  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups. For other conversation types, pass null.
  • userTypingStatus Collection of users whose typing status has changed

Implementation

Function(
  RCIMIWConversationType? type,
  String? targetId,
  String? channelId,
  List<RCIMIWTypingStatus>? userTypingStatus,
)?
onTypingStatusChanged;