removeChatRoomEntries method

Future<int> removeChatRoomEntries(
  1. String targetId,
  2. List<String> keys,
  3. bool force, {
  4. IRCIMIWRemoveChatRoomEntriesCallback? callback,
})

ZH

批量删除聊天室自定义属性

  • targetId 聊天室会话 ID
  • keys 聊天室属性
  • force 是否强制覆盖
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onChatRoomEntriesRemoved

EN

Batch Delete Chatroom Custom Attributes

  • targetId The chatroom conversation ID
  • keys The chatroom attributes
  • force Specifies whether to force overwrite
  • callback The event callback. SDK supports callback mode from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and will be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful invocation, and specific results need to be handled in the interface callback. Non-zero values indicate that the current interface invocation failed, and no callback will be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> removeChatRoomEntries(
  String targetId,
  List<String> keys,
  bool force, {
  IRCIMIWRemoveChatRoomEntriesCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.removeChatRoomEntries(targetId, keys, force, callback: callback);
}