removeChatRoomEntry method

Future<int> removeChatRoomEntry(
  1. String targetId,
  2. String key,
  3. bool force, {
  4. IRCIMIWRemoveChatRoomEntryCallback? callback,
})

ZH

删除聊天室自定义属性。

  • targetId 聊天室会话 ID
  • key 聊天室属性键值
  • force 是否强制删除
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onChatRoomEntryRemoved

EN

Remove chatroom custom attributes.

  • targetId The chatroom conversation ID
  • key The chatroom attribute key
  • force Whether to force deletion
  • callback The event callback. SDK supports callback method starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero indicates that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> removeChatRoomEntry(
  String targetId,
  String key,
  bool force, {
  IRCIMIWRemoveChatRoomEntryCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.removeChatRoomEntry(targetId, key, force, callback: callback);
}