removeFromBlacklist method

Future<int> removeFromBlacklist(
  1. String userId, {
  2. IRCIMIWRemoveFromBlacklistCallback? callback,
})

ZH

将某个用户从黑名单中移出。

  • userId 用户 Id
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onBlacklistRemoved

EN

Remove a user from the blocklist.

  • userId User ID
  • callback Event callback. The SDK supports callback-based event handling starting from version 5.3.1. Other callback methods for this interface have been deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If a callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented through the interface callback. Non-zero values indicate that the current operation failed, and no callback will be triggered. Refer to the error codes for detailed error information.

此接口不支持 Flutter For Web 端

Implementation

Future<int> removeFromBlacklist(String userId, {IRCIMIWRemoveFromBlacklistCallback? callback}) async {
  return RCIMWrapperPlatform.instance.removeFromBlacklist(userId, callback: callback);
}