removeNotificationQuietHours method

Future<int> removeNotificationQuietHours({
  1. IRCIMIWRemoveNotificationQuietHoursCallback? callback,
})

ZH

删除已设置的全局时间段消息提醒屏蔽

  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onNotificationQuietHoursRemoved

EN

Remove the globally set time period message reminder mute

  • callback Event callback. The SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be implemented via the interface callback. Non-zero indicates that the current interface call operation failed, and no interface callback will be triggered. Refer to the error codes for detailed errors.

此接口不支持 Flutter For Web 端

Implementation

Future<int> removeNotificationQuietHours({IRCIMIWRemoveNotificationQuietHoursCallback? callback}) async {
  return RCIMWrapperPlatform.instance.removeNotificationQuietHours(callback: callback);
}