saveDraftMessage method
Future<int>
saveDraftMessage(
- RCIMIWConversationType type,
- String targetId,
- String? channelId,
- String draft, {
- IRCIMIWSaveDraftMessageCallback? callback,
ZH
保存会话草稿信息。
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。draft草稿的文字内容。callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onDraftMessageSaved
EN
Save conversation draft information.
typeConversation typetargetIdConversation IDchannelIdChannel ID, only supported for ultra groups. Pass null for other conversation types.draftThe text content of the draft.callbackEvent callback. The SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero values indicate that the current operation failed, and no interface callback will be triggered. For detailed error information, refer to the error codes.
Implementation
Future<int> saveDraftMessage(
RCIMIWConversationType type,
String targetId,
String? channelId,
String draft, {
IRCIMIWSaveDraftMessageCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.saveDraftMessage(type, targetId, channelId, draft, callback: callback);
}