sendGroupReadReceiptResponse method

Future<int> sendGroupReadReceiptResponse(
  1. String targetId,
  2. String? channelId,
  3. List<RCIMIWMessage> messages, {
  4. IRCIMIWSendGroupReadReceiptResponseCallback? callback,
})

ZH

发送群聊已读回执

  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • messages 会话中需要发送已读回执的消息列表
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onGroupReadReceiptResponseSent

EN

Send Group Read Receipt

  • targetId Conversation ID
  • channelId Channel ID, only supported for ultra groups. Pass null for other conversation types.
  • messages List of messages in the conversation for which read receipts need to be sent
  • callback Event callback. SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. and the specific result requires implementing the interface callback. Non-zero values indicate that the current operation failed, and no callback will be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> sendGroupReadReceiptResponse(
  String targetId,
  String? channelId,
  List<RCIMIWMessage> messages, {
  IRCIMIWSendGroupReadReceiptResponseCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.sendGroupReadReceiptResponse(targetId, channelId, messages, callback: callback);
}