sendMessage method
ZH
发送普通消息
message发送的消息实体callback发送消息的事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调接口回调可以监听 onMessageAttached,onMessageSent
EN
Send a Normal Message
messageThe message object to be sent.callbackThe event callback for sending the message. The SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be handled via the interface callback. A non-zero value indicates that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information. @listener The interface callback can listen to onMessageAttached, onMessageSent.
Implementation
Future<int> sendMessage(RCIMIWMessage message, {RCIMIWSendMessageCallback? callback}) async {
return RCIMWrapperPlatform.instance.sendMessage(message, callback: callback);
}