sendPrivateReadReceiptMessage method

Future<int> sendPrivateReadReceiptMessage(
  1. String targetId,
  2. String? channelId,
  3. int timestamp, {
  4. IRCIMIWSendPrivateReadReceiptMessageCallback? callback,
})

ZH

发送某个会话中的消息阅读回执

  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • timestamp 该会话中已读的最后一条消息的发送时间戳
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onPrivateReadReceiptMessageSent

EN

Send a read receipt for messages in a specific conversation.

  • targetId The conversation ID.
  • channelId The channel ID, only supported for ultra groups. Pass null for other conversation types.
  • timestamp The timestamp of the last read message in the conversation.
  • callback The event callback. SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be implemented via the interface callback. Non-zero values indicate that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.

Implementation

Future<int> sendPrivateReadReceiptMessage(
  String targetId,
  String? channelId,
  int timestamp, {
  IRCIMIWSendPrivateReadReceiptMessageCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.sendPrivateReadReceiptMessage(
    targetId,
    channelId,
    timestamp,
    callback: callback,
  );
}