sendTypingStatus method

Future<int> sendTypingStatus(
  1. RCIMIWConversationType type,
  2. String targetId,
  3. String? channelId,
  4. String currentType,
)

ZH

向会话中发送正在输入的状态,目前只支持单聊。

  • type 会话类型
  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用,其他会话类型传 null 即可。
  • currentType 当前的状态
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码

EN

Send a typing status to the conversation. Currently, this feature is only supported in one-to-one chats.

  • type Specifies the conversation type
  • targetId Specifies the conversation ID
  • channelId Specifies the channel ID, which is only supported for ultra groups. For other conversation types, pass null.
  • currentType Specifies the current status call, and the specific result needs to be implemented through the callback interface. A non-zero value indicates that the call failed and will not trigger the callback. Refer to the error codes for detailed error information.

Implementation

Future<int> sendTypingStatus(
  RCIMIWConversationType type,
  String targetId,
  String? channelId,
  String currentType,
) async {
  return RCIMWrapperPlatform.instance.sendTypingStatus(type, targetId, channelId, currentType);
}