syncUltraGroupReadStatus method

Future<int> syncUltraGroupReadStatus(
  1. String targetId,
  2. String? channelId,
  3. int timestamp, {
  4. IRCIMIWSyncUltraGroupReadStatusCallback? callback,
})

ZH

上报超级群的已读时间

  • targetId 会话 ID
  • channelId 频道 ID,仅支持超级群使用。
  • timestamp 已读时间
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onUltraGroupReadStatusSynced

EN

Report the read time of an ultra group.

  • targetId The conversation ID.
  • channelId The channel ID, only supported for ultra groups.
  • timestamp The read time.
  • callback The event callback. The SDK supports callback-style responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be handled in the callback. Non-zero values indicate a failure in the current operation, and no callback will be triggered. Refer to the error codes for detailed error information.

timestamp 在 Flutter For Web 端无效

Implementation

Future<int> syncUltraGroupReadStatus(
  String targetId,
  String? channelId,
  int timestamp, {
  IRCIMIWSyncUltraGroupReadStatusCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.syncUltraGroupReadStatus(targetId, channelId, timestamp, callback: callback);
}