updateMessageExpansion method
Future<int>
updateMessageExpansion(
- String messageUId,
- Map expansion, {
- IRCIMIWUpdateMessageExpansionCallback? callback,
ZH
更新消息扩展信息 每条消息携带扩展信息键值对最大值 300个,单次设置扩展信息键值对最大值 20个
messageUId消息的 messageUid,可在消息对象中获取,且只有发送成功的消息才会有值expansion要更新的消息扩展信息键值对,类型是 HashMap;Key 支持大小写英文字母、数字、部分特殊符号 + = - _ 的组合方式,不支持汉字。Value 可以输入空格callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onMessageExpansionUpdated
EN
Update Message Extension Information Each message can carry a maximum of 300 key-value pairs of extension information, and a single update can set a maximum of 20 key-value pairs.
messageUIdThe messageUid of the message, which can be obtained from the message object. Only successfully sent messages will have a value.expansionThe key-value pairs of message extension information to be updated, of type HashMap. The Key supports a combination of uppercase and lowercase English letters, numbers, and some special symbols + = - _. Chinese characters are not supported. The Value can include spaces.callbackThe event callback. The SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented in the interface callback. Non-zero indicates that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.
Implementation
Future<int> updateMessageExpansion(
String messageUId,
Map expansion, {
IRCIMIWUpdateMessageExpansionCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.updateMessageExpansion(messageUId, expansion, callback: callback);
}