updateUltraGroupMessageExpansion method

Future<int> updateUltraGroupMessageExpansion(
  1. String messageUId,
  2. Map expansion, {
  3. IRCIMIWUpdateUltraGroupMessageExpansionCallback? callback,
})

ZH

更新超级群消息扩展信息

  • messageUId 消息的 messageUid,可在消息对象中获取,且只有发送成功的消息才会有值
  • expansion 更新的消息扩展信息键值对,类型是 HashMap;Key 支持大小写英文字母、数字、部分特殊符号 + = - _ 的组合方式,不支持汉字。Value 可以输入空格。
  • callback 事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。
  • 返回值 当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
  • 接口回调 onUltraGroupMessageExpansionUpdated

EN

Update Ultra Group Message Extension Information

  • messageUId The messageUid of the message, which can be obtained from the message object. Only successfully sent messages will have a value.
  • expansion The key-value pairs for the updated message extension information, of type HashMap. Key supports a combination of uppercase and lowercase English letters, numbers, and special characters + = - _. Chinese characters are not supported. Value can include spaces.
  • callback The event callback. SDK supports callback method starting from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be implemented in the interface callback. Non-zero indicates a failure in the current interface call operation, and the interface callback will not be triggered. Refer to the error codes for detailed errors.

Implementation

Future<int> updateUltraGroupMessageExpansion(
  String messageUId,
  Map expansion, {
  IRCIMIWUpdateUltraGroupMessageExpansionCallback? callback,
}) async {
  return RCIMWrapperPlatform.instance.updateUltraGroupMessageExpansion(messageUId, expansion, callback: callback);
}