fileServer property
ZH
私有部署的媒体服务器地址,即文件和图片的上传地址。使用私有云时必须填写。
EN
The media server address for private deployment, which is the upload address for files and images. This field is mandatory when using a private cloud.
Implementation
String? fileServer;