kickReconnectDevice property

bool? kickReconnectDevice
getter/setter pair

ZH

设置断线重连时是否踢出重连设备。 用户没有开通多设备登录功能的前提下,同一个账号在一台新设备上登录的时候,会把这个账号在之前登录的设备上踢出。

EN

Set whether to kick out the reconnecting device during reconnection. When a user has not enabled the multi-device login feature, if the same account logs in on a new device, the account will be kicked out from the previously logged-in device.

Implementation

bool? kickReconnectDevice;