RCIMIWFriendInfo class

Constructors

RCIMIWFriendInfo.create({String? userId, String? name, String? portrait, String? remark, Map? extFields, int? addTime, RCIMIWFriendType? friendType})
RCIMIWFriendInfo.fromJson(Map<String, dynamic> json)

Properties

addTime int?
ZH
getter/setter pair
extFields Map?
ZH
getter/setter pair
friendType RCIMIWFriendType?
ZH
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
ZH
getter/setter pair
portrait String?
ZH
getter/setter pair
remark String?
ZH
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited