RCIMIWGroupReadReceiptInfo class
Constructors
-
RCIMIWGroupReadReceiptInfo.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasRespond ↔ bool?
-
ZHgetter/setter pair - readReceiptMessage ↔ bool?
-
ZHgetter/setter pair - respondUserIds ↔ Map?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited