RCIMIWLogLevel enum

Inheritance
Available extensions

Values

none → const RCIMIWLogLevel

ZH

不输出任何日志

EN

Do not output any logs.

error → const RCIMIWLogLevel

ZH

只输出错误的日志

EN

Only output error logs.

warn → const RCIMIWLogLevel

ZH

输出错误和警告的日志

EN

Logs output errors and warnings.

info → const RCIMIWLogLevel

ZH

输出错误、警告和一般的日志

EN

Output errors, warnings, and general logs.

debug → const RCIMIWLogLevel

ZH

输出错误、警告和一般的日志以及 debug 日志

EN

Output errors, warnings, general logs, and debug logs.

verbose → const RCIMIWLogLevel

ZH

输出所有日志

EN

Output All Logs

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWLogLevel>
A constant List of the values in this enum, in order of their declaration.