RCIMIWMentionedInfo class
Constructors
-
RCIMIWMentionedInfo.create({RCIMIWMentionedType? type, List<
String> ? userIdList, String? mentionedContent}) -
RCIMIWMentionedInfo.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mentionedContent ↔ String?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ RCIMIWMentionedType?
-
ZHgetter/setter pair -
userIdList
↔ List<
String> ? -
ZHgetter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited