expansion property
ZH
消息扩展信息,发消息前设置该属性可打开消息扩展功能,否则无法使用消息扩展功能。
发送成功后需使用 updateMessageExpansion 接口更新扩展信息。
消息扩展 key 长度不超过 32 ,value 长度不超过 4096 ,单次设置扩展数量最大为 20,消息的扩展总数不能超过 300
注: 扩展信息只支持单聊和群组,其它会话类型不能设置扩展信息
EN
Message expansion information. Set this property before sending a message to enable the message expansion feature; otherwise, the message expansion feature cannot be used.
After sending a message successfully, use the updateMessageExpansion interface to update the expansion information.
Message extension key length should not exceed 32 characters, and value length should not exceed 4096 characters. The maximum number of extensions that can be set at one time is 20, and the total number of extensions for a message cannot exceed 300."
Note: Extension information is only supported for private chats and groups; extension information cannot be set for other conversation types.
Implementation
Map? expansion;