messageId property

int? messageId
getter/setter pair

ZH

本地数据库中存储的消息的唯一 ID 值。发送新消息时无需指定该 ID,否则会导致消息入库失败。在失败重发消息时,可以填入已入库的消息的 ID,请确保使用上一次发送失败的消息实例。

EN

The unique ID value of the message stored in the local database. This ID does not need to be specified when sending a new message; otherwise, it will cause the message to fail to be stored in the database. When retrying a failed message, you can fill in the ID of the message that has already been stored. Ensure that you use the message instance from the previous failed attempt.

Implementation

int? messageId;