RCIMIWMessageAuditInfo class
Constructors
- RCIMIWMessageAuditInfo.create({RCIMIWMessageAuditType? auditType, String? project, String? strategy})
-
RCIMIWMessageAuditInfo.fromJson(Map<
String, dynamic> json)
Properties
- auditType ↔ RCIMIWMessageAuditType?
-
ZHgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- project ↔ String?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy ↔ String?
-
ZHgetter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited