RCIMIWMessagePushOptions class

Constructors

RCIMIWMessagePushOptions.create({bool? disableNotification, bool? disablePushTitle, String? pushTitle, String? pushContent, String? pushData, bool? forceShowDetailContent, String? templateId, bool? voIPPush, RCIMIWIOSPushOptions? iOSPushOptions, RCIMIWAndroidPushOptions? androidPushOptions, RCIMIWHarmonyPushOptions? harmonyPushOptions})
RCIMIWMessagePushOptions.fromJson(Map<String, dynamic> json)

Properties

androidPushOptions RCIMIWAndroidPushOptions?
ZH
getter/setter pair
disableNotification bool?
ZH
getter/setter pair
disablePushTitle bool?
ZH
getter/setter pair
forceShowDetailContent bool?
ZH
getter/setter pair
harmonyPushOptions RCIMIWHarmonyPushOptions?
ZH
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iOSPushOptions RCIMIWIOSPushOptions?
ZH
getter/setter pair
pushContent String?
ZH
getter/setter pair
pushData String?
ZH
getter/setter pair
pushTitle String?
ZH
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
templateId String?
ZH
getter/setter pair
voIPPush bool?
ZH
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited