RCIMIWMessageType enum

Inheritance
Available extensions

Values

unknown → const RCIMIWMessageType

ZH

无效类型

EN

Invalid Type

custom → const RCIMIWMessageType

ZH

自定义

EN

Custom

text → const RCIMIWMessageType

ZH

文本

EN

Text

voice → const RCIMIWMessageType

ZH

语音

EN

Voice

image → const RCIMIWMessageType

ZH

图片

EN

Image

file → const RCIMIWMessageType

ZH

文件

EN

File

sight → const RCIMIWMessageType

ZH

小视频

EN

Short video

gif → const RCIMIWMessageType

ZH

GIF 图

EN

GIF Image

recall → const RCIMIWMessageType

ZH

撤回

EN

Recall

reference → const RCIMIWMessageType

ZH

引用

EN

Reference

command → const RCIMIWMessageType

ZH

命令

EN

Command

commandNotification → const RCIMIWMessageType

ZH

命令通知

EN

Command Notification

location → const RCIMIWMessageType

ZH

位置消息

EN

Location Message

userCustom → const RCIMIWMessageType

ZH

用户自定义消息

EN

User Custom Message

nativeCustom → const RCIMIWMessageType

ZH

原生自定义普通消息

EN

Native Custom Message

stream → const RCIMIWMessageType

ZH

流式消息

EN

Stream Message

nativeCustomMedia → const RCIMIWMessageType

ZH

原生自定义媒体消息

EN

Native Custom Media Message

groupNotification → const RCIMIWMessageType

ZH

群通知消息

EN

Group Notification Message

combineV2 → const RCIMIWMessageType

ZH

合并转发V2消息

EN

Combine V2 Message

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWMessageType>
A constant List of the values in this enum, in order of their declaration.