RCIMIWReceivedStatus enum

Inheritance
Available extensions

Values

unread → const RCIMIWReceivedStatus

ZH

未读

EN

Unread

read → const RCIMIWReceivedStatus

ZH

已读

EN

Read

listened → const RCIMIWReceivedStatus

ZH

已听

EN

Listened

downloaded → const RCIMIWReceivedStatus

ZH

已下载

EN

Downloaded.

retrieved → const RCIMIWReceivedStatus

ZH

该消息已经被其他登录的多端收取过。(即该消息已经被其他端收取过后。当前端才登录,并重新拉取了这条消息。客户可以通过这个状态更新 UI,比如不再提示)

EN

The message has already been received by other devices logged in with the same account. (This means the message was received by other devices before the current device logged in and re-fetched the message. Clients can use this status to update the UI, e.g., stop displaying notifications.)

multipleReceive → const RCIMIWReceivedStatus

ZH

该消息是被多端同时收取的。(即其他端正同时登录,一条消息被同时发往多端。客户可以通过这个状态值更新自己的某些 UI 状态)。

EN

The message is simultaneously received by multiple endpoints (i.e., other endpoints are logged in at the same time, and a single message is sent to multiple endpoints simultaneously). Clients can use this status value to update certain UI states.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWReceivedStatus>
A constant List of the values in this enum, in order of their declaration.