RCIMIWReceivedStatusInfo class
Constructors
- RCIMIWReceivedStatusInfo.create({bool? read, bool? listened, bool? downloaded, bool? retrieved})
-
RCIMIWReceivedStatusInfo.fromJson(Map<
String, dynamic> json)
Properties
- downloaded ↔ bool?
-
ZHgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- listened ↔ bool?
-
ZHgetter/setter pair - read ↔ bool?
-
ZHgetter/setter pair - retrieved ↔ bool?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited