RCIMIWSentStatus enum

Inheritance
Available extensions

Values

sending → const RCIMIWSentStatus

ZH

发送中

EN

Sending

failed → const RCIMIWSentStatus

ZH

发送失败

EN

Send failed

sent → const RCIMIWSentStatus

ZH

已发送

EN

Sent

received → const RCIMIWSentStatus

ZH

对方已接收

EN

The message has been received by the recipient.

read → const RCIMIWSentStatus

ZH

对方已读

EN

The message has been read by the recipient.

destroyed → const RCIMIWSentStatus

ZH

对方已销毁

EN

The other party has been deactivated.

canceled → const RCIMIWSentStatus

ZH

对方已取消

EN

The other party has canceled.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RCIMIWSentStatus>
A constant List of the values in this enum, in order of their declaration.