RCIMIWUserInfo class
Constructors
- RCIMIWUserInfo.create({String? userId, String? name, String? portrait, String? alias, String? extra})
-
RCIMIWUserInfo.fromJson(Map<
String, dynamic> json)
Properties
- alias ↔ String?
-
ZHgetter/setter pair - extra ↔ String?
-
ZHgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
ZHgetter/setter pair - portrait ↔ String?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
ZHgetter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited