RCIMIWAreaCode enum
Values
- bj → const RCIMIWAreaCode
-
ZH北京数据中心,默认值
ENBeijing Data Center, default value
- sg → const RCIMIWAreaCode
-
ZH新加坡数据中心
ENSingapore Data Center
- na → const RCIMIWAreaCode
-
ZH北美数据中心
ENNorth America Data Center
- sgB → const RCIMIWAreaCode
-
ZH新加坡 B 企业合作数据中心
ENSingapore B Enterprise Collaboration Data Center
- sa → const RCIMIWAreaCode
-
ZH沙特数据中心
ENChina (Beijing) Data Center
- om → const RCIMIWAreaCode
-
ZH阿曼数据中心
ENOman Data Center
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RCIMIWAreaCode> - A constant List of the values in this enum, in order of their declaration.