RCIMIWCompressOptions class
Constructors
- RCIMIWCompressOptions.create({int? originalImageQuality, int? originalImageSize, int? originalImageMaxSize, int? thumbnailQuality, int? thumbnailMaxSize, int? thumbnailMinSize, int? sightCompressWidth, int? sightCompressHeight, int? locationThumbnailQuality, int? locationThumbnailWidth, int? locationThumbnailHeight})
-
RCIMIWCompressOptions.fromJson(Map<
String, dynamic> json)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationThumbnailHeight ↔ int?
-
ZHgetter/setter pair - locationThumbnailQuality ↔ int?
-
ZHgetter/setter pair - locationThumbnailWidth ↔ int?
-
ZHgetter/setter pair - originalImageMaxSize ↔ int?
-
ZHgetter/setter pair - originalImageQuality ↔ int?
-
ZHgetter/setter pair - originalImageSize ↔ int?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sightCompressHeight ↔ int?
-
ZHgetter/setter pair - sightCompressWidth ↔ int?
-
ZHgetter/setter pair - thumbnailMaxSize ↔ int?
-
ZHgetter/setter pair - thumbnailMinSize ↔ int?
-
ZHgetter/setter pair - thumbnailQuality ↔ int?
-
ZHgetter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited