RCIMIWConversation class
Constructors
- RCIMIWConversation.create({RCIMIWConversationType? conversationType, String? targetId, String? channelId, int? unreadCount, int? mentionedCount, int? mentionedMeCount, bool? top, String? draft, RCIMIWMessage? lastMessage, RCIMIWPushNotificationLevel? notificationLevel, int? firstUnreadMsgSendTime, int? operationTime, RCIMIWTranslateStrategy? translateStrategy})
-
RCIMIWConversation.fromJson(Map<
String, dynamic> json)
Properties
- channelId ↔ String?
-
ZHgetter/setter pair - conversationType ↔ RCIMIWConversationType?
-
ZHgetter/setter pair - draft ↔ String?
-
ZHgetter/setter pair - firstUnreadMsgSendTime ↔ int?
-
ZHgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- lastMessage ↔ RCIMIWMessage?
-
ZHgetter/setter pair - mentionedCount ↔ int?
-
ZHgetter/setter pair - mentionedMeCount ↔ int?
-
ZHgetter/setter pair - notificationLevel ↔ RCIMIWPushNotificationLevel?
-
ZHgetter/setter pair - operationTime ↔ int?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetId ↔ String?
-
ZHgetter/setter pair - top ↔ bool?
-
ZHgetter/setter pair - translateStrategy ↔ RCIMIWTranslateStrategy?
-
ZHgetter/setter pair - unreadCount ↔ int?
-
ZHgetter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited