RCIMIWConversationType enum
Values
- invalid → const RCIMIWConversationType
-
ZH暂不支持,SDK 保留类型,开发者不可使用
ENNot supported. Reserved type for SDK, not available for developers.
- private → const RCIMIWConversationType
-
ZH单聊会话
ENOne-to-One Chat Conversation
- group → const RCIMIWConversationType
-
ZH群聊会话
ENGroup Chat Conversation
- chatroom → const RCIMIWConversationType
-
ZH聊天室会话
ENChatroom Conversation
- system → const RCIMIWConversationType
-
ZH系统会话
ENSystem Conversation
- ultraGroup → const RCIMIWConversationType
-
ZH超级群会话
ENUltra Group Conversation
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RCIMIWConversationType> - A constant List of the values in this enum, in order of their declaration.