addChatRoomEntries method
Future<int>
addChatRoomEntries(
- String targetId,
- Map entries,
- bool deleteWhenLeft,
- bool overwrite, {
- IRCIMIWAddChatRoomEntriesCallback? callback,
ZH
批量设置聊天室自定义属性
targetId聊天室会话 IDentries聊天室属性deleteWhenLeft用户掉线或退出时,是否自动删除该 Key、Value 值overwrite是否强制覆盖callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onChatRoomEntriesAdded
EN
Batch Set Chatroom Custom Attributes
targetIdChatroom conversation IDentriesChatroom attributesdeleteWhenLeftWhether to automatically delete the Key and Value when the user goes offline or exitsoverwriteWhether to force overwritecallbackEvent callback. The SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be implemented through the interface callback. A non-zero value indicates that the current interface call failed, and the interface callback will not be triggered. For detailed errors, refer to the error codes.
Implementation
Future<int> addChatRoomEntries(
String targetId,
Map entries,
bool deleteWhenLeft,
bool overwrite, {
IRCIMIWAddChatRoomEntriesCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.addChatRoomEntries(
targetId,
entries,
deleteWhenLeft,
overwrite,
callback: callback,
);
}