changeConversationTopStatus method
Future<int>
changeConversationTopStatus(
- RCIMIWConversationType type,
- String targetId,
- String? channelId,
- bool top, {
- IRCIMIWChangeConversationTopStatusCallback? callback,
ZH
设置会话的置顶状态。若会话不存在,调用此方法 SDK 自动创建会话并置顶。
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。top是否置顶callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onConversationTopStatusChanged
EN
Sets the pinned status of a conversation. If the conversation does not exist, calling this method will automatically create and pin the conversation.
typeSpecifies the conversation type.targetIdSpecifies the conversation ID.channelIdSpecifies the channel ID, which is only supported for ultra groups. For other conversation types, pass null.topIndicates whether to pin the conversation.callbackSpecifies the event callback. The SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface were deprecated in version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be implemented in the interface callback. Non-zero values indicate that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.
此接口在 Flutter For Web 端不支持超级群
Implementation
Future<int> changeConversationTopStatus(
RCIMIWConversationType type,
String targetId,
String? channelId,
bool top, {
IRCIMIWChangeConversationTopStatusCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.changeConversationTopStatus(type, targetId, channelId, top, callback: callback);
}