clearMessages method
Future<int>
clearMessages(
- RCIMIWConversationType type,
- String targetId,
- String? channelId,
- int timestamp,
- RCIMIWMessageOperationPolicy policy, {
- IRCIMIWClearMessagesCallback? callback,
ZH
清除消息
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。timestamp清除消息截止时间戳,0 ≤ timestamp ≤ 当前会话最后一条消息的 sentTime, 0 清除所有消息,其他值清除小于等于 timestamp 的消息policy清除的策略callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onMessagesCleared
EN
Clear Messages
typeConversation typetargetIdConversation IDchannelIdChannel ID, only supported for ultra groups. Pass null for other conversation types.timestampTimestamp for clearing messages up to a certain time. 0 ≤ timestamp ≤ sentTime of the last message in the current conversation. 0 clears all messages, other values clear messages with sentTime ≤ timestamp.policyClearing policycallbackEvent callback. SDK supports callback mode starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and will be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. Specific results need to be handled in the interface callback. Non-zero indicates the current operation failed and no callback will be triggered. Refer to the error code for details.
Implementation
Future<int> clearMessages(
RCIMIWConversationType type,
String targetId,
String? channelId,
int timestamp,
RCIMIWMessageOperationPolicy policy, {
IRCIMIWClearMessagesCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.clearMessages(type, targetId, channelId, timestamp, policy, callback: callback);
}