clearUltraGroupMessages method
Future<int>
clearUltraGroupMessages(
- String targetId,
- String? channelId,
- int timestamp,
- RCIMIWMessageOperationPolicy policy, {
- IRCIMIWClearUltraGroupMessagesCallback? callback,
ZH
删除超级群指定时间之前的消息
targetId会话 IDchannelId频道 ID,仅支持超级群使用。timestamp时间戳policy清除策略callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onUltraGroupMessagesCleared
EN
Delete messages in an ultra group before a specified time
targetIdConversation IDchannelIdChannel ID, only supported for ultra groups.timestampUnix timestamppolicyClear policycallbackEvent callback. SDK supports callback method from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. and the specific result needs to be implemented through the interface callback. Non-zero indicates a failure in the current operation, and the interface callback will not be triggered. Refer to the error codes for detailed error information.
Implementation
Future<int> clearUltraGroupMessages(
String targetId,
String? channelId,
int timestamp,
RCIMIWMessageOperationPolicy policy, {
IRCIMIWClearUltraGroupMessagesCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.clearUltraGroupMessages(
targetId,
channelId,
timestamp,
policy,
callback: callback,
);
}