clearUnreadCount method
Future<int>
clearUnreadCount(
- RCIMIWConversationType type,
- String targetId,
- String? channelId,
- int timestamp, {
- IRCIMIWClearUnreadCountCallback? callback,
ZH
清除某个会话中的未读消息数。 注:不支持聊天室!
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。timestamp该会话已阅读的最后一条消息的发送时间戳,清除所有传入当前最新时间戳callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onUnreadCountCleared
EN
Clear the unread message count for a specific conversation. Note: Not supported for chatrooms!
typeConversation typetargetIdConversation IDchannelIdChannel ID, only supported for ultra groups. Pass null for other conversation types.timestampThe timestamp of the last read message in the conversation. Pass the latest timestamp to clear all.callbackEvent callback. The SDK supports callback-based responses starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and will be removed in the 6.x version. If the callback parameter is provided, only the callback method will be triggered. call, and the specific result needs to be handled by the callback. Non-zero values indicate the operation failed, and no callback will be triggered. Refer to the error codes for details.
Implementation
Future<int> clearUnreadCount(
RCIMIWConversationType type,
String targetId,
String? channelId,
int timestamp, {
IRCIMIWClearUnreadCountCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.clearUnreadCount(type, targetId, channelId, timestamp, callback: callback);
}