getChatRoomEntry method
Future<int>
getChatRoomEntry(
- String targetId,
- String key, {
- IRCIMIWGetChatRoomEntryCallback? callback,
ZH
获取聊天室单个属性。
targetId聊天室会话 IDkey聊天室属性键值callback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve a single chatroom attribute.
targetIdThe conversation ID of the chatroomkeyThe key of the chatroom attributecallbackThe event callback. SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be handled in the interface callback. Non-zero values indicate that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information. @listener onChatRoomEntryLoaded
Implementation
Future<int> getChatRoomEntry(String targetId, String key, {IRCIMIWGetChatRoomEntryCallback? callback}) async {
return RCIMWrapperPlatform.instance.getChatRoomEntry(targetId, key, callback: callback);
}