getConversation method
Future<int>
getConversation(
- RCIMIWConversationType type,
- String targetId,
- String? channelId, {
- IRCIMIWGetConversationCallback? callback,
ZH
获取某个会话
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可callback获取会话事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve a Conversation
typeConversation typetargetIdConversation IDchannelIdChannel ID, only supported for ultra groups. For other conversation types, pass null.callbackCallback for retrieving the conversation. SDK supports callback method from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and will be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. and the specific result needs to be handled in the interface callback. Non-zero values indicate a failure in the current operation, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onConversationLoaded
Implementation
Future<int> getConversation(
RCIMIWConversationType type,
String targetId,
String? channelId, {
IRCIMIWGetConversationCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.getConversation(type, targetId, channelId, callback: callback);
}