getDraftMessage method
Future<int>
getDraftMessage(
- RCIMIWConversationType type,
- String targetId,
- String? channelId, {
- IRCIMIWGetDraftMessageCallback? callback,
ZH
获取会话中的草稿信息。
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。callback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve draft information from a conversation.
typeConversation typetargetIdConversation IDchannelIdChannel ID, supported only for ultra groups. Pass null for other conversation types.callbackEvent callback. The SDK supports callback-based event handling starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be handled in the interface callback. Non-zero values indicate a failed operation, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onDraftMessageLoaded
Implementation
Future<int> getDraftMessage(
RCIMIWConversationType type,
String targetId,
String? channelId, {
IRCIMIWGetDraftMessageCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.getDraftMessage(type, targetId, channelId, callback: callback);
}