getMessageById method
ZH
根据消息 id 获取消息体(本地数据库索引唯一值)。
messageId消息的 messageId,可在消息对象中获取callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve the message body based on the message ID (unique value in the local database index).
messageIdThe messageId of the message, which can be obtained from the message object.callbackThe event callback. The SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. successful call, and the specific result needs to be implemented in the interface callback. Non-zero indicates that the current interface call operation failed, and the interface callback will not be triggered. For detailed errors, refer to the error codes.
此接口不支持 Flutter For Web 端
Implementation
Future<int> getMessageById(int messageId, {IRCIMIWGetMessageCallback? callback}) async {
return RCIMWrapperPlatform.instance.getMessageById(messageId, callback: callback);
}