getUltraGroupUnreadMentionedCount method
Future<int>
getUltraGroupUnreadMentionedCount(
- String targetId, {
- IRCIMIWGetUltraGroupUnreadMentionedCountCallback? callback,
ZH
获取超级群会话中被 @ 的消息数
targetId会话 IDcallback事件回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Retrieve the count of mentioned messages in an ultra group
conversation
targetIdThe conversation IDcallbackThe event callback. SDK supports callback-style events starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If a callback parameter is provided, only the callback will be triggered. call, and specific results need to be handled via the interface callback. Non-zero values indicate that the current operation failed, and no callback will be triggered. Refer to the error codes for detailed error information. @listener onUltraGroupUnreadMentionedCountLoaded
Implementation
Future<int> getUltraGroupUnreadMentionedCount(
String targetId, {
IRCIMIWGetUltraGroupUnreadMentionedCountCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.getUltraGroupUnreadMentionedCount(targetId, callback: callback);
}