joinChatRoom method
Future<int>
joinChatRoom(
- String targetId,
- int messageCount,
- bool autoCreate, {
- IRCIMIWJoinChatRoomCallback? callback,
ZH
加入聊天室。
targetId聊天室会话 IDmessageCount进入聊天室拉取消息数目,-1 时不拉取任何消息,0 时拉取 10 条消息,最多只能拉取 50autoCreate是否创建聊天室,TRUE 如果聊天室不存在,sdk 会创建聊天室并加入,如果已存在,则直接加入callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onChatRoomJoined
EN
Join a chatroom.
targetIdThe chatroom conversation IDmessageCountThe number of messages to fetch upon entering the chatroom. -1 means no messages will be fetched, 0 means fetching 10 messages, with a maximum of 50 messages allowed.autoCreateWhether to create the chatroom. If TRUE and the chatroom does not exist, the SDK will create the chatroom and join it. If the chatroom already exists, the SDK will directly join it.callbackEvent callback. The SDK supports callback-based events starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be handled by the interface callback. Non-zero values indicate a failure in the current operation, and no interface callback will be triggered. Refer to the error codes for detailed error information.
Implementation
Future<int> joinChatRoom(
String targetId,
int messageCount,
bool autoCreate, {
IRCIMIWJoinChatRoomCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.joinChatRoom(targetId, messageCount, autoCreate, callback: callback);
}