loadBatchRemoteUltraGroupMessages method
- @Deprecated('请使用 [getBatchRemoteUltraGroupMessages] 代替')
- List<
RCIMIWMessage> messages
ZH
从服务获取批量消息
messages获取的消息集合返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onBatchRemoteUltraGroupMessagesLoaded {@link #getBatchRemoteUltraGroupMessages(List, IRCIMIWGetBatchRemoteUltraGroupMessagesCallback)} 代替, 预计将在 6.x 版本删除此接口。
EN
Retrieve Batch Messages from Service
messagesThe collection of messages to be retrieved call, and the specific result requires the implementation of the interface callback. Non-zero indicates that the current interface call operation failed, and the interface callback will not be triggered. For detailed errors, refer to the error codes. @deprecated Use {@link #getBatchRemoteUltraGroupMessages(List, IRCIMIWGetBatchRemoteUltraGroupMessagesCallback)} instead. This interface is expected to be removed in version 6.x.
Implementation
@Deprecated('请使用 [getBatchRemoteUltraGroupMessages] 代替')
Future<int> loadBatchRemoteUltraGroupMessages(List<RCIMIWMessage> messages) async {
return RCIMWrapperPlatform.instance.loadBatchRemoteUltraGroupMessages(messages);
}