loadUnreadCountByConversationTypes method
- @Deprecated('请使用 [getUnreadCountByConversationTypes] 代替')
- List<
RCIMIWConversationType> conversationTypes, - String? channelId,
- bool contain
ZH
根据会话类型加载未读数 注:不支持聊天室!
conversationTypes会话类型集合channelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。contain是否包含免打扰消息的未读消息数。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onUnreadCountByConversationTypesLoaded {@link #getUnreadCountByConversationTypes(List, String, boolean, IRCIMIWGetUnreadCountByConversationTypesCallback)} 代替, 预计将在 6.x 版本删除此接口。
EN
Load Unread Count by Conversation Type Note: Not supported for chatrooms!
conversationTypesSpecifies the collection of conversation types.channelIdIndicates the channel ID. This parameter is only supported for ultra groups. For other conversation types, passnull.containIndicates whether to include unread messages from muted conversations. success, and the specific result requires implementing the callback interface. Non-zero values indicate failure, and no callback will be triggered. Refer to the error codes for detailed information. @deprecated Use {@link #getUnreadCountByConversationTypes(List, String, boolean, IRCIMIWGetUnreadCountByConversationTypesCallback)} instead. This interface is expected to be removed in version 6.x.
此接口在 Flutter For Web 端不支持设置 channelId
Implementation
@Deprecated('请使用 [getUnreadCountByConversationTypes] 代替')
Future<int> loadUnreadCountByConversationTypes(
List<RCIMIWConversationType> conversationTypes,
String? channelId,
bool contain,
) async {
return RCIMWrapperPlatform.instance.loadUnreadCountByConversationTypes(conversationTypes, channelId, contain);
}