modifyUltraGroupMessage method
Future<int>
modifyUltraGroupMessage(
- String messageUId,
- RCIMIWMessage message, {
- IRCIMIWModifyUltraGroupMessageCallback? callback,
ZH
修改超级群消息
messageUId消息的 messageUid,可在消息对象中获取,且只有发送成功的消息才会有值message要修改的 messagecallback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onUltraGroupMessageModified
EN
Modify Ultra Group Message
messageUIdThe messageUid of the message, which can be obtained from the message object. Only successfully sent messages will have a value.messageThe message to be modified.callbackEvent callback. SDK supports callback-style callbacks starting from version 5.3.1. Other callback methods for this interface are deprecated as of version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. call, and the specific result needs to be handled by the interface callback. Non-zero values indicate that the current operation failed, and no interface callback will be triggered. Refer to the error codes for detailed error information.
Implementation
Future<int> modifyUltraGroupMessage(
String messageUId,
RCIMIWMessage message, {
IRCIMIWModifyUltraGroupMessageCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.modifyUltraGroupMessage(messageUId, message, callback: callback);
}