onBatchRemoteUltraGroupMessagesLoaded property
- @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
getter/setter pair
ZH
loadBatchRemoteUltraGroupMessages 的接口监听
code接口回调的状态码,0 代表成功,非 0 代表出现异常matchedMessages从服务获取的消息列表notMatchedMessages非法参数或者从服务没有拿到对应消息 @deprecated 请使用对应接口提供的 callback 获取结果。
EN
loadBatchRemoteUltraGroupMessages Interface Listener
codeIndicates the status code of the interface callback. 0 represents success, while non-zero indicates an exception.matchedMessagesRepresents the list of messages retrieved from the service.matchedMessagesSpecifies messages that were not retrieved due to invalid parameters or absence from the service. @deprecated Please use the callback provided by the corresponding interface to obtain the results.
Implementation
@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, List<RCIMIWMessage>? matchedMessages, List<RCIMIWMessage>? notMatchedMessages)?
onBatchRemoteUltraGroupMessagesLoaded;