onConversationReadStatusSynced property
- @Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
getter/setter pair
ZH
syncConversationReadStatus 的接口监听
code接口回调的状态码,0 代表成功,非 0 代表出现异常type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。timestamp会话中已读的最后一条消息的发送时间戳 @deprecated 请使用对应接口提供的 callback 获取结果。
EN
Listener for the syncConversationReadStatus interface
codeStatus code of the interface callback. 0 indicates success, non-zero indicates an exception.typeConversation typetargetIdConversation IDchannelIdChannel ID, only supported for ultra groups. For other conversation types, pass null.timestampTimestamp of the last read message in the conversation @deprecated Please use the callback provided by the corresponding interface to obtain the result.
Implementation
@Deprecated('建议在调用接口时直接传入 callback 参数,此回调从 5.4.0 版本开始不推荐使用')
Function(int? code, RCIMIWConversationType? type, String? targetId, String? channelId, int? timestamp)?
onConversationReadStatusSynced;