onGroupMessageReadReceiptResponseReceived property
dynamic Function(String? targetId, String? messageUId, Map? respondUserIds)?
onGroupMessageReadReceiptResponseReceived
getter/setter pair
ZH
收到群聊已读回执响应的监听
targetId会话 IDmessageUId收到回执响应的消息的 messageUIdrespondUserIds会话中响应了此消息的用户列表。其中 key: 用户 id ; value: 响应时间。
EN
Listener for Group Chat Read Receipt Response
targetIdConversation IDmessageUIdMessage UID of the message for which the read receipt response was receivedrespondUserIdsList of users in the conversation who responded to this message. The key is the user ID, and the value is the response time.
Implementation
Function(String? targetId, String? messageUId, Map? respondUserIds)? onGroupMessageReadReceiptResponseReceived;