removeConversations method
Future<int>
removeConversations(
- List<
RCIMIWConversationType> conversationTypes, - String? channelId, {
- IRCIMIWRemoveConversationsCallback? callback,
ZH
根据会话类型移除会话
conversationTypes会话类型集合channelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。callback移除会话列表事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onConversationsRemoved
EN
Remove conversations based on conversation type
conversationTypesA collection of conversation typeschannelIdChannel ID, only supported for ultra groups. Pass null for other conversation types.callbackCallback for the conversation removal event. SDK supports callback method from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and will be removed in version 6.x. If the callback parameter is provided, only the callback method will be triggered. and the specific result needs to be handled in the interface callback. Non-zero values indicate a failure in the current operation, and no callback will be triggered. Refer to the error codes for detailed error information.
此接口不支持 Flutter For Web 端
Implementation
Future<int> removeConversations(
List<RCIMIWConversationType> conversationTypes,
String? channelId, {
IRCIMIWRemoveConversationsCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.removeConversations(conversationTypes, channelId, callback: callback);
}