searchConversations method
Future<int>
searchConversations(
- List<
RCIMIWConversationType> conversationTypes, - String? channelId,
- List<
RCIMIWMessageType> messageTypes, - String keyword, {
- IRCIMIWSearchConversationsCallback? callback,
ZH
根据关键字搜索会话。
conversationTypes会话类型集合channelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。messageTypes搜索的消息类型keyword搜索的关键字。callback事件回调。SDK 从 5.3.1 版本开始支持 callback 方式回调。从 5.4.0 版本废弃该接口的其他回调方式,预计将在 6.x 版本删除此其他回调方式。如果传入了 callback 参数,仅触发 callback 回调。返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码接口回调onConversationsSearched
EN
Search conversations by keyword.
conversationTypesCollection of conversation typeschannelIdChannel ID, only supported for ultra groups. Pass null for other conversation types.messageTypesMessage types to search forkeywordKeyword to search forcallbackEvent callback. SDK supports callback mode from version 5.3.1. Other callback methods for this interface are deprecated starting from version 5.4.0 and are expected to be removed in version 6.x. If the callback parameter is provided, only the callback will be triggered. Specific results need to be implemented via the interface callback. Non-zero values indicate that the current interface call operation failed and will not trigger the interface callback. Refer to the error codes for detailed error information.
此接口不支持 Flutter For Web 端
Implementation
Future<int> searchConversations(
List<RCIMIWConversationType> conversationTypes,
String? channelId,
List<RCIMIWMessageType> messageTypes,
String keyword, {
IRCIMIWSearchConversationsCallback? callback,
}) async {
return RCIMWrapperPlatform.instance.searchConversations(
conversationTypes,
channelId,
messageTypes,
keyword,
callback: callback,
);
}