sendTypingStatus method
Future<int>
sendTypingStatus(
- RCIMIWConversationType type,
- String targetId,
- String? channelId,
- String currentType,
ZH
向会话中发送正在输入的状态,目前只支持单聊。
type会话类型targetId会话 IDchannelId频道 ID,仅支持超级群使用,其他会话类型传 null 即可。currentType当前的状态返回值当次接口操作的状态码。0 代表调用成功 具体结果需要实现接口回调,非 0 代表当前接口调用操作失败,不会触发接口回调,详细错误参考错误码
EN
Send a typing status to the conversation. Currently, this feature is only supported in one-to-one chats.
typeSpecifies the conversation typetargetIdSpecifies the conversation IDchannelIdSpecifies the channel ID, which is only supported for ultra groups. For other conversation types, pass null.currentTypeSpecifies the current status call, and the specific result needs to be implemented through the callback interface. A non-zero value indicates that the call failed and will not trigger the callback. Refer to the error codes for detailed error information.
Implementation
Future<int> sendTypingStatus(
RCIMIWConversationType type,
String targetId,
String? channelId,
String currentType,
) async {
return RCIMWrapperPlatform.instance.sendTypingStatus(type, targetId, channelId, currentType);
}