offLine property
ZH
是否是离线消息,只在接收消息的回调方法中有效,如果消息为离线消息,则为 YES ,其他情况均为 NO
EN
Indicates whether the message is an offline message. This is only valid in the message received callback method. If the message is an offline message, the value is YES; otherwise, it is NO.
Implementation
bool? offLine;