RCIMIWMessagePushOptions class
Constructors
- RCIMIWMessagePushOptions.create({bool? disableNotification, bool? disablePushTitle, String? pushTitle, String? pushContent, String? pushData, bool? forceShowDetailContent, String? templateId, bool? voIPPush, RCIMIWIOSPushOptions? iOSPushOptions, RCIMIWAndroidPushOptions? androidPushOptions, RCIMIWHarmonyPushOptions? harmonyPushOptions})
-
RCIMIWMessagePushOptions.fromJson(Map<
String, dynamic> json)
Properties
- androidPushOptions ↔ RCIMIWAndroidPushOptions?
-
ZHgetter/setter pair - disableNotification ↔ bool?
-
ZHgetter/setter pair - disablePushTitle ↔ bool?
-
ZHgetter/setter pair - forceShowDetailContent ↔ bool?
-
ZHgetter/setter pair - harmonyPushOptions ↔ RCIMIWHarmonyPushOptions?
-
ZHgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- iOSPushOptions ↔ RCIMIWIOSPushOptions?
-
ZHgetter/setter pair - pushContent ↔ String?
-
ZHgetter/setter pair - pushData ↔ String?
-
ZHgetter/setter pair - pushTitle ↔ String?
-
ZHgetter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateId ↔ String?
-
ZHgetter/setter pair - voIPPush ↔ bool?
-
ZHgetter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited