RCIMIWMessageType enum
Values
- unknown → const RCIMIWMessageType
-
ZH无效类型
ENInvalid Type
- custom → const RCIMIWMessageType
-
ZH自定义
ENCustom
- text → const RCIMIWMessageType
-
ZH文本
ENText
- voice → const RCIMIWMessageType
-
ZH语音
ENVoice
- image → const RCIMIWMessageType
-
ZH图片
ENImage
- file → const RCIMIWMessageType
-
ZH文件
ENFile
- sight → const RCIMIWMessageType
-
ZH小视频
ENShort video
- gif → const RCIMIWMessageType
-
ZHGIF 图
ENGIF Image
- recall → const RCIMIWMessageType
-
ZH撤回
ENRecall
- reference → const RCIMIWMessageType
-
ZH引用
ENReference
- command → const RCIMIWMessageType
-
ZH命令
ENCommand
- commandNotification → const RCIMIWMessageType
-
ZH命令通知
ENCommand Notification
- location → const RCIMIWMessageType
-
ZH位置消息
ENLocation Message
- userCustom → const RCIMIWMessageType
-
ZH用户自定义消息
ENUser Custom Message
- nativeCustom → const RCIMIWMessageType
-
ZH原生自定义普通消息
ENNative Custom Message
- stream → const RCIMIWMessageType
-
ZH流式消息
ENStream Message
- nativeCustomMedia → const RCIMIWMessageType
-
ZH原生自定义媒体消息
ENNative Custom Media Message
- groupNotification → const RCIMIWMessageType
-
ZH群通知消息
ENGroup Notification Message
- combineV2 → const RCIMIWMessageType
-
ZH合并转发V2消息
ENCombine V2 Message
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RCIMIWMessageType> - A constant List of the values in this enum, in order of their declaration.