RCIMIWPushNotificationLevel enum
Values
- allMessage → const RCIMIWPushNotificationLevel
-
ZH与融云服务端断开连接后,当前用户可针对指定类型会话中的所有消息接收通知。
ENAfter disconnecting from the RongCloud server, the current user can receive notifications for all messages in specified conversation types.
- none → const RCIMIWPushNotificationLevel
-
ZH未设置。未设置时均为此初始状态。
ENNot set. This is the initial state when no value is set.
- mention → const RCIMIWPushNotificationLevel
-
ZH与融云服务端断开连接后,当前用户仅针对指定类型的会话中提及(@)当前用户和全体群成员的消息接收通知。
ENAfter disconnecting from the RongCloud server, the current user will only receive notifications for messages that mention (@) the current user or all group members in specified types of conversations.
- mentionUsers → const RCIMIWPushNotificationLevel
-
ZH与融云服务端断开连接后,当前用户仅针对指定类型的会话中提及(@)当前用户的消息接收通知。例如:张三只会接收 “@张三 Hello” 的消息的通知。
ENAfter disconnecting from the RongCloud server, the current user will only receive notifications for messages that mention (@) them in specified conversation types. For example, Zhang San will only receive notifications for messages like @Zhang San Hello.
- mentionAll → const RCIMIWPushNotificationLevel
-
ZH与融云服务端断开连接后,当前用户仅针对指定类型的会话中提及(@)全部群成员的消息接收通知。
ENAfter disconnecting from the RongCloud server, the current user will only receive notifications for messages that mention (@) all group members in specified types of conversations.
- blocked → const RCIMIWPushNotificationLevel
-
ZH当前用户针对指定类型的会话中的任何消息都不接收推送通知。
ENThe current user does not receive push notifications for any messages in the specified type of conversation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RCIMIWPushNotificationLevel> - A constant List of the values in this enum, in order of their declaration.