RCIMIWPushNotificationQuietHoursLevel enum
Values
- none → const RCIMIWPushNotificationQuietHoursLevel
-
ZH未设置。如未设置,SDK 会依次查询消息所属群的用户级别免打扰设置及其他非用户级别设置,再判断是否需要推送通知。
ENNot set. If not set, the SDK will sequentially check the user-level Do Not Disturb settings of the group to which the message belongs, as well as other non-user-level settings, to determine whether a push notification is required.
- mentionMessage → const RCIMIWPushNotificationQuietHoursLevel
-
ZH与融云服务端断开连接后,当前用户仅在指定时段内针对指定会话中提及(@)当前用户和全体群成员的消息接收通知。
ENAfter disconnecting from the RongCloud server, the current user will only receive notifications for messages that mention (@) the current user and all group members in specified conversations within a designated time period.
- blocked → const RCIMIWPushNotificationQuietHoursLevel
-
ZH当前用户在指定时段内针对任何消息都不接收推送通知。
ENThe current user will not receive push notifications for any messages during the specified time period.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RCIMIWPushNotificationQuietHoursLevel> - A constant List of the values in this enum, in order of their declaration.