RCIMIWSentStatus enum
Values
- sending → const RCIMIWSentStatus
-
ZH发送中
ENSending
- failed → const RCIMIWSentStatus
-
ZH发送失败
ENSend failed
- sent → const RCIMIWSentStatus
-
ZH已发送
ENSent
- received → const RCIMIWSentStatus
-
ZH对方已接收
ENThe message has been received by the recipient.
- read → const RCIMIWSentStatus
-
ZH对方已读
ENThe message has been read by the recipient.
- destroyed → const RCIMIWSentStatus
-
ZH对方已销毁
ENThe other party has been deactivated.
- canceled → const RCIMIWSentStatus
-
ZH对方已取消
ENThe other party has canceled.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RCIMIWSentStatus> - A constant List of the values in this enum, in order of their declaration.